# Original information ---------------------------------------------
#
# Line Sketch script by kward1979uk
# last modified/tested by Paul Sherman
#
# End original information -----------------------------------------

from gimpfu import *

############################################################################
# Lines Sketch
#---------------------------------------------------------------------------

def LineSketch210 (inImage, inDrawable, EdgeType, BGcolour):
    
    pdb.gimp_context_push()
    
    Name = inDrawable.name
    if '.' in Name:
        split = Name.split(".", 1)
        Name = split[0]
        
    Width = inDrawable.width
    Height = inDrawable.height
    
    SketchedImg = pdb.gimp_image_new (Width, Height, RGB_IMAGE)
    SketchedDrw = pdb.gimp_layer_new_from_drawable (inDrawable, SketchedImg)
    TypeDesc=["0=Sobel", "1=Prewitt","2=Gradient","3=Roberts","4=Differential","5=Laplace"]
    SketchedDrw.name = Name+", sketched (EdgeType"+TypeDesc[EdgeType]+")"
    SketchedImg.add_layer (SketchedDrw, 0)
    
    EdgeAmount=2.0; EdgeWrap=2
    pdb.plug_in_edge (SketchedImg, SketchedDrw, EdgeAmount, EdgeWrap, EdgeType)
    pdb.gimp_drawable_equalize (SketchedDrw, False)
    pdb.gimp_drawable_desaturate (SketchedDrw, DESATURATE_LUMA)
    
    HighPassDrw = SketchedDrw.copy()
    SketchedImg.add_layer (HighPassDrw, 1)
    pdb.gimp_drawable_curves_spline (HighPassDrw, HISTOGRAM_VALUE, 10,
                                ( 0.00,0.00, 0.74,0.00, 0.75,0.01, 0.82,0.82, 1.00,1.00) 
                               )
    pdb.gimp_drawable_invert (SketchedDrw, True)
    pdb.gimp_layer_add_alpha (SketchedDrw)
    imagemask = pdb.gimp_layer_create_mask (SketchedDrw, ADD_WHITE_MASK)
    SketchedDrw.add_mask (imagemask)
    pdb.gimp_edit_copy (HighPassDrw)
    copypaste = pdb.gimp_edit_paste (imagemask, False)
    pdb.gimp_floating_sel_anchor (copypaste)
    SketchedImg.remove_layer (HighPassDrw)
    
    BG = pdb.gimp_layer_new (SketchedImg, Width, Height, RGB_IMAGE, "Background", 100.0, LAYER_MODE_NORMAL)
    SketchedImg.add_layer (BG, 1)
    pdb.gimp_context_set_foreground (BGcolour)
    pdb.gimp_drawable_fill (BG, FILL_FOREGROUND)
    
    pdb.gimp_display_new (SketchedImg)
    pdb.gimp_context_pop()
    
    return(SketchedDrw)

register(
    "LineSketch210",
    "LineSketch 210",
    "Apply a Line Sketch technique.",
    "Diego",
    "Diego Nassetti (Open source: BSD 3-clause license)",
    "2018",
    "Line Sketch (for Gimp 2.10)",
    "RGB, RGB*",
    [
      (PF_IMAGE, "image", "Input image", None),
      (PF_DRAWABLE, "drawable", "Input drawable", None),
      (PF_OPTION, "type", "Type of edge", 0, ["0=Sobel", "1=Prewitt", "2=Gradient",
                                              "3=Roberts", "4=Differential", "5=Laplace"]),
      (PF_COLOR, "bgcol", "Colour of BG", ((255,255,255,255))),
    ],
    [
      (PF_DRAWABLE, "outdrawable", "Output drawable", None),
    ],
    LineSketch210,
    menu="<Image>/Diego/Draw"
    )

main()
